@@ -107,12 +107,15 @@ def _to_np_array(obj) -> np.ndarray:
 class Scene:
     def __init__(self, title : str = "Scene"):
         """
-        Scene for NeRF visualization. Add objects using :code:`add_*` and :code:`set_nerf` then use
-        :code:`export()`/:code:`display()` to create a
-        standalone web viewer you can open in a browser.
-        Alternatively,
-        use :code:`--draw` argument of the desktop volrend program or
-        via :code:`Load Local` button of the online viewer.
+        Holds radiance field/volume/mesh/point cloud/lines objects for 3D visualization.
+        Add objects using :code:`add_*` as seen below, then use
+        :code:`export()`/:code:`display()`/:code:`embed()` to create a
+        standalone web viewer you can open in a browser or embed in
+        a notebook.
+
+        - Single scene quick import:  `from nerfvis import scene`
+
+        - Multiple scenes:  `from nerfvis import Scene` then `scene = Scene('title')`
 
         :param title: title to show when saving, default 'Scene'.
                       You can change it later by setting scene.title = '...'.
@@ -225,7 +228,7 @@ class Scene:
         :param rotation: (3,), model rotation in axis-angle (common param)
         :param scale:  float, scale, default 1.0 (common param)
         :param visible: bool, whether mesh should be visible on init, default true (depends on GET parameter in web version) (common param)
-        :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param unlit: bool, whether mesh should be rendered unlit. Default True (common param)
         :param time: int, time at which the mesh should be displayed; -1=always display (default)
                     (common param)
         """
@@ -299,7 +302,7 @@ class Scene:
         :param scale:  float, scale, default 1.0 (common param)
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
-        :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param unlit: bool, whether mesh should be rendered unlit. Default true (common param)
         :param time: int, time at which the mesh should be displayed; -1=always display (default)
                     (common param)
         """
@@ -330,7 +333,7 @@ class Scene:
         :param scale:  float, scale, default 1.0 (common param)
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
-        :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param unlit: bool, whether mesh should be rendered unlit. Default true (common param)
         :param time: int, time at which the mesh should be displayed; -1=always display (default)
                     (common param)
         """
@@ -360,12 +363,10 @@ class Scene:
         :param scale:  float, scale, default 1.0 (common param)
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
-        :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param unlit: bool, whether mesh should be rendered unlit. Default true (common param)
         :param time: int, time at which the mesh should be displayed; -1=always display (default)
                     (common param)
         """
-        if 'unlit' not in kwargs:
-            kwargs['unlit'] = True   # Default unlit points
         self._add_common(name, **kwargs)
         points = _to_np_array(points)
         self.fields[name] = "points"
@@ -385,9 +386,10 @@ class Scene:
         :param name: an identifier for this object
         :param points: (N, 3) float, list of points
         :param faces: (N, face_size) int, list of faces; if not given,
-                faces will be something like 1-2-3, 4-5-6, 7-8-9, etc
+                faces will be :code:`0-1-2, 3-4-5, 6-7-8`, etc (glDrawArrays)
         :param face_size: int, one of 1,2,3. 3 means triangle mesh,
-                1 means point cloud, and 2 means lines
+                1 means point cloud, and 2 means lines. By default is determined from faces
+                (usually 3).
         :param color: (3,) color, default is orange (common param)
         :param vert_color: (N, 3) vertex color, optional (overrides color) (common param)
         :param translation: (3,), model translation (common param)
@@ -395,7 +397,9 @@ class Scene:
         :param scale:  float, scale, default 1.0 (common param)
         :param visible: bool, whether mesh should be visible on init, default true
                         (depends on GET parameter in web version) (common param)
-        :param unlit: bool, whether mesh should be rendered unlit (common param)
+        :param unlit: bool, whether mesh should be rendered unlit.
+                            Use this if you want to render vertex colors directly 
+                            without lighting. Default false. (common param)
         :param time: int, time at which the mesh should be displayed; -1=always display (default)
                     (common param)
         """
@@ -434,8 +438,8 @@ class Scene:
                   or positive values for OpenCV coordinates (NSVF).
                   If not given, tries to infer a good value. Else defaults to -0.3
                   NOTE: kind of weirdly (but to be consistent
-                       with add_camera_frustum),for OpenGL, z needs to be negative,
-                       while for OpenCV it should be positive.
+                  with add_camera_frustum),for OpenGL, z needs to be negative,
+                  while for OpenCV it should be positive.
         :param image_size: size of image for display (only if using path)
         :param opengl: if True use OpenGL coordinates (NeRF default);
                        else use OpenCV. Default: depends on if set_opencv()
@@ -662,7 +666,11 @@ class Scene:
 
     def remove(self, name : str):
         """
-        Remove an object with given name
+        Remove an object with given name.
+        Note: if you overwrite an object with the same name
+        type and arguments, it will overwrite the
+        object in the scene.
+
         :param name: the name given to add_*
         """
         self.remove_all([name])
@@ -670,6 +678,7 @@ class Scene:
     def remove_all(self, names : List[str]):
         """
         Remove object with given names
+
         :param names: list of names as given to add_*
         """
         to_delete = []
@@ -683,7 +692,7 @@ class Scene:
 
     def clear(self):
         """
-        Clear all objects
+        Clear all objects from the scene.
         """
         self.fields.clear()
 
@@ -693,6 +702,7 @@ class Scene:
                    colors : np.ndarray,
                    radius: float = 1.0,
                    density_threshold: float = 1.0,
+                   data_format: str = "RGBA",
                    **kwargs
                ):
         """
@@ -721,7 +731,9 @@ class Scene:
         density = _to_np_array(density)
         colors = _to_np_array(colors)
         tree_data = utils.vol2plenoctree(
-                density, colors, radius, density_threshold=density_threshold)
+                density, colors, radius,
+                density_threshold=density_threshold,
+                data_format=data_format)
         self._add_common(name, **kwargs)
         self.fields[name] = "volume"
         for k in tree_data:
@@ -1012,9 +1024,13 @@ class Scene:
 
     def write(self, path : str, compress : bool = True):
         """
-        Write to drawlist npz which you can open with volrend (:code:`--draw`)
-        as well as in the web viewer.
-        Discretized NeRF will not be exported. Usually, it's easier to use Scene.export()
+        Write to drawlist npz which you can open with volrend
+        (:code:`volrend --draw <output.npz>`;
+         nerfvis_base branch recommended for more up-to-date experience)
+        as well as in the web viewer. Usually, it's easier to use one of
+        :code:`Scene.export()`,
+        :code:`Scene.display()`, or
+        :code:`Scene.emebd()`
 
         :param path: output npz path
         """
@@ -1043,8 +1059,8 @@ class Scene:
         """
         Write to a standalone web viewer
 
-        :param dirname: output folder path, if not given then uses nerfvis_scenes/(0-9a-zA-Z_ from self.title)
-        :param display: if true, serves the output using http.server and opens the browser
+        :param dirname: output folder path, if not given then uses :code:`./nerfvis_scenes/(0-9a-zA-Z_ from self.title)`
+        :param display: if true, serves the output using http.server (default false)
         :param world_up: (3,), optionally, world up unit vector for mouse orbiting
                                (will try to infer from cameras from add_camera_frustum if not given)
         :param cam_center: (3,), optionally, camera center point
@@ -1058,7 +1074,7 @@ class Scene:
         :param url: str, URL for server (if display=True) default localhost
         :param port: int, port for server (if display=True) default 8888
                         (if not available, tries next up to 32)
-        :param open_browser: bool, if true then opens the web browser, if possible (default)
+        :param open_browser: bool, if true then opens the web browser, if possible (default False)
 
         :return: dirname, if it was not provided, returns the generated folder name;
                  url
@@ -1198,7 +1214,26 @@ class Scene:
 
     def display(self, *args, **kwargs) -> Tuple[str, str]:
         """
-        Alias of :code:`Scene.export` with :code:`display=True` (show in webbrowser)
+        Alias of :code:`Scene.export` with :code:`display=True` (serve using http.server)
+
+        :param dirname: output folder path, if not given then uses :code:`./nerfvis_scenes/(0-9a-zA-Z_ from self.title)`
+        :param world_up: (3,), optionally, world up unit vector for mouse orbiting
+                               (will try to infer from cameras from add_camera_frustum if not given)
+        :param cam_center: (3,), optionally, camera center point
+                               (will try to infer from cameras from add_camera_frustum if not given)
+        :param cam_forward: (3,), optionally, camera forward-pointing vector
+                               (will try to infer from cameras from add_camera_frustum if not given)
+        :param cam_origin: (3,), optionally, camera center of rotation point
+                               (will try to infer from cameras from add_camera_frustum if not given)
+        :param compress: whether to compress the output npz file (slower but smaller)
+        :param instructions: list of additional javascript instructions to execute (advanced)
+        :param url: str, URL for server (if display=True) default localhost
+        :param port: int, port for server (if display=True) default 8888
+                        (if not available, tries next up to 32)
+        :param open_browser: bool, if true then opens the web browser, if possible (default False)
+
+        :return: dirname, if it was not provided, returns the generated folder name;
+                 url
         """
         return self.export(*args, display=True, **kwargs)
 
@@ -1210,6 +1245,25 @@ class Scene:
         Calls :code:`Scene.export` but in addition embeds inside a notebook;
         still requires port to be forwarded if on a server. Use port=..
         to chose one if desired (default 8888)
+
+        :param dirname: output folder path, if not given then uses :code:`./nerfvis_scenes/(0-9a-zA-Z_ from self.title)`
+        :param world_up: (3,), optionally, world up unit vector for mouse orbiting
+                               (will try to infer from cameras from add_camera_frustum if not given)
+        :param cam_center: (3,), optionally, camera center point
+                               (will try to infer from cameras from add_camera_frustum if not given)
+        :param cam_forward: (3,), optionally, camera forward-pointing vector
+                               (will try to infer from cameras from add_camera_frustum if not given)
+        :param cam_origin: (3,), optionally, camera center of rotation point
+                               (will try to infer from cameras from add_camera_frustum if not given)
+        :param compress: whether to compress the output npz file (slower but smaller)
+        :param instructions: list of additional javascript instructions to execute (advanced)
+        :param url: str, URL for server (if display=True) default localhost
+        :param port: int, port for server (if display=True) default 8888
+                        (if not available, tries next up to 32)
+        :param open_browser: bool, if true then opens the web browser, if possible (default False)
+
+        :return: dirname, if it was not provided, returns the generated folder name;
+                 url
         """
         from IPython.display import display, IFrame  # Requires IPython
         _, url = self.export(*args, display=True, open_browser=False,
